@@ -6,6 +6,8 @@ call.eqs <- function(EQSpgm, EQSmodel, serial, Rmatrix = NA, datname = NA, LEN =
   #LEN ... Number of working array unit.  By default, it is 2,000,000 8 bytes units
   
   #--------- change working directory where eqs file is located ---------
+  if (!file.exists(EQSmodel)) stop("The .eqs file not found in the current folder!")
+  
   filedir.split <- strsplit(EQSmodel, "/")[[1]]
   n <- length(filedir.split) 
   filedir <- paste(filedir.split[1:(n-1)], collapse = "/")
@@ -35,11 +37,10 @@ call.eqs <- function(EQSpgm, EQSmodel, serial, Rmatrix = NA, datname = NA, LEN =
 
   EQScmd <- paste(deparse(EQSpgm), filepathin, fileout, lenstring, serstring)
   
-  RetCode <- system(EQScmd, intern = FALSE, ignore.stderr = TRUE, wait = TRUE, input = NULL,
-      show.output.on.console = FALSE, minimized = FALSE, invisible = FALSE)
-  
-  RetCode <- system(EQScmd, intern = FALSE, ignore.stderr = TRUE, wait = TRUE, input = NULL,
-      show.output.on.console = FALSE, minimized = FALSE, invisible = FALSE)
+  #RetCode <- system(EQScmd, intern = FALSE, ignore.stderr = TRUE, wait = TRUE, input = NULL,
+  #    show.output.on.console = FALSE, minimized = FALSE, invisible = FALSE)
+      
+  RetCode <- system(EQScmd, intern = FALSE, ignore.stderr = TRUE, wait = TRUE, input = NULL)
   
   return(RetCode)
 }
