@@ -1,6 +1,6 @@
-run.eqs <- function(EQSpgm, EQSmodel, serial, data = NA, datname = NA, LEN = 2000000)
+run.eqs <- function(EQSpgm, EQSmodel, serial, Rmatrix = NA, datname = NA, LEN = 2000000)
 {
-  res <- call.eqs(EQSpgm = EQSpgm, EQSmodel = EQSmodel, serial = serial, data = data, datname = datname, LEN = LEN)
+  res <- call.eqs(EQSpgm = EQSpgm, EQSmodel = EQSmodel, serial = serial, Rmatrix = Rmatrix, datname = datname, LEN = LEN)
   
   if (res == -1) warning("EQS estimation not successful!")
   
